# coding: utf-8

"""
    Cashfree Payment Gateway APIs

    Cashfree's Payment Gateway APIs provide developers with a streamlined pathway to integrate advanced payment processing capabilities into their applications, platforms and websites.

    The version of the OpenAPI document: 2023-08-01
    Contact: developers@cashfree.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, constr

class CreatePlanRequest(BaseModel):
    """
    Request body to create a plan.
    """
    plan_id: constr(strict=True, max_length=40, min_length=1) = Field(..., description="Unique ID to identify the plan. Only alpha-numerics, dot, hyphen and underscore allowed.")
    plan_name: constr(strict=True, max_length=40, min_length=1) = Field(..., description="Name of the plan.")
    plan_type: StrictStr = Field(..., description="Type of the plan. Possible values - PERIODIC, ON_DEMAND.")
    plan_currency: Optional[StrictStr] = Field(None, description="Currency of the plan.")
    plan_recurring_amount: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="Recurring amount for the plan. Required for PERIODIC plan_type.")
    plan_max_amount: Union[StrictFloat, StrictInt] = Field(..., description="Maximum amount for the plan.")
    plan_max_cycles: Optional[StrictInt] = Field(None, description="Maximum number of payment cycles for the plan.")
    plan_intervals: Optional[StrictInt] = Field(None, description="Number of billing cycles between charges. For instance, if set to 2 and the interval type is 'week', the service will be billed every 2 weeks. Similarly, if set to 3 and the interval type is 'month', the service will be billed every 3 months. Required for PERIODIC plan_type.")
    plan_interval_type: Optional[StrictStr] = Field(None, description="Interval type for the plan. Possible values - DAY, WEEK, MONTH, YEAR.")
    plan_note: Optional[StrictStr] = Field(None, description="Note for the plan.")
    __properties = ["plan_id", "plan_name", "plan_type", "plan_currency", "plan_recurring_amount", "plan_max_amount", "plan_max_cycles", "plan_intervals", "plan_interval_type", "plan_note"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreatePlanRequest:
        """Create an instance of CreatePlanRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))
    
    @classmethod
    def from_json_for_one_of(cls, json_str: str) -> CreatePlanRequest:
        """Create an instance of CreatePlanRequest from a JSON string"""
        temp_dict = json.loads(json_str)
        if "plan_id, plan_name, plan_type, plan_currency, plan_recurring_amount, plan_max_amount, plan_max_cycles, plan_intervals, plan_interval_type, plan_note" in temp_dict.keys():
            return cls.from_dict(json.loads(json_str))
        return None

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreatePlanRequest:
        """Create an instance of CreatePlanRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreatePlanRequest.parse_obj(obj)

        _obj = CreatePlanRequest.parse_obj({
            "plan_id": obj.get("plan_id"),
            "plan_name": obj.get("plan_name"),
            "plan_type": obj.get("plan_type"),
            "plan_currency": obj.get("plan_currency"),
            "plan_recurring_amount": obj.get("plan_recurring_amount"),
            "plan_max_amount": obj.get("plan_max_amount"),
            "plan_max_cycles": obj.get("plan_max_cycles"),
            "plan_intervals": obj.get("plan_intervals"),
            "plan_interval_type": obj.get("plan_interval_type"),
            "plan_note": obj.get("plan_note")
        })
        return _obj


